# swimbundle-utils


Python package repo for Swimlane Utils
<br />
Included utilities
See Quickstart: https://github.com/swimlane/swimbundle-utils/wiki/Quickstart
<table>
    <tr>
        <td><b>Name</b></td>
        <td><b>Description</b></td>
    <tr>
        <td>flattener</td>
        <td>flatten json dicts and lists, with other useful dict-related functions</td>
    </tr>
    <tr>
        <td>rest</td>
        <td>basic rest api mixin, pagination support, and other common rest functions</td>
    </tr>
    <tr>
        <td>exceptions</td>
        <td>Useful common exceptions for Swimlane Bundles</td>
    </tr>
    <tr>
        <td>helpers</td>
        <td>Helper funcs for making code for Swimbundles, includes validation</td>
    </tr>
    <tr>
        <td>validation</td>
        <td>More advanced tools for validating inputs</td>
    </tr>
    <tr>
        <td>ioc</td>
        <td>Parse IOCs out of text and determine the type of an IOC</td>
    </tr>
</table>
